4.52. umbra.ui.widgets.application_QToolBar — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.52. umbra.ui.widgets.application_QToolBar

application_QToolBar.py.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Application_QToolBar` class.

Others:

## 4.52.1. Module Attributes

`umbra.ui.widgets.application_QToolBar.` `LOGGER`

## 4.52.2. Classes

class `umbra.ui.widgets.application_QToolBar.` `Application_QToolBar`(parent=None)

  Bases: `PyQt4.QtGui.QToolBar`

  This class is a QToolBar subclass providing the Application toolbar.

  Parameters: | parent – Widget parent. ( QObject )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( Preferences )

  `layoutsActiveLabelsCollection`

    This method is the property for self.__layoutsActiveLabelsCollection attribute.

    Returns: | self.__layoutsActiveLabelsCollection. ( Active_QLabelsCollection )

  `customLayoutsMenu`

    This method is the property for self.__customLayoutsMenu attribute.

    Returns: | self.__customLayoutsMenu. ( QMenu )

  `miscellaneousMenu`

    This method is the property for self.__miscellaneousMenu attribute.

    Returns: | self.__miscellaneousMenu. ( QMenu )

  `setLayoutDefaultGeometry`()

    This method sets the toolBar layout default geometry.

    Returns: | Method success. ( Boolean )

  `setToolBarChildrenWidgets`()

    This method sets the toolBar children widgets.

    Returns: | Method success. ( Boolean )

  `getApplicationLogoLabel`()

    This method provides the default Application_Logo_label widget.

    Returns: | Application logo label. ( QLabel )

  `getLayoutActiveLabel`(resources, name, title, identity, shortcut)

    This method returns a layout Active_QLabel widget.

    Parameters: | resources – Icons resources ( Default / Hover / Active ). ( Tuple ) name – Ui object name. ( String ) title – Layout registration title. ( String ) identity – Layout code name. ( String ) shortcut – Layout associated shortcut. ( QtCore.Key )
    Returns: | Layout active label. ( Active_QLabel )

  `getLayoutsActiveLabels`()

    This method returns the layouts Active_QLabel widgets.

    Returns: | Layouts active labels. ( List )

  `getCustomLayoutsActiveLabel`()

    This method provides the default Custom_Layouts_activeLabel widget.

    Returns: | Layout active label. ( Active_QLabel )

  `getMiscellaneousActiveLabel`()

    This method provides the default Miscellaneous_activeLabel widget.

    Returns: | Miscellaneous active label. ( Active_QLabel )

  `getSpacerLabel`()

    This method provides the default Spacer_label widget.

    Returns: | Logo spacer label. ( QLabel )

  `getClosureSpacerLabel`()

    This method provides the default Closure_Spacer_label widget.

    Returns: | Closure spacer label. ( QLabel )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »